==> undertaker_1.5.orig.tar.xz: undertaker-1.5/undertaker/validation/checkexpr_complex.c <==
/*
 * check-name: find interesting items for symbol
 * check-command: undertaker -j checkexpr -m ../kconfig-dumps/models/x86.model CONFIG_SND_HDA_INTEL
 * check-output-start
CONFIG_64BIT=n
CONFIG_ANON_INODES=y
CONFIG_ARCH_HAS_CACHE_LINE_SIZE=y
CONFIG_ARCH_HAS_CPU_IDLE_WAIT=y
CONFIG_ARCH_HAS_CPU_RELAX=y
CONFIG_ARCH_HAS_DEFAULT_IDLE=y
CONFIG_ARCH_HIBERNATION_POSSIBLE=y
CONFIG_ARCH_MAY_HAVE_PC_FDC=y
CONFIG_ARCH_POPULATES_NODE_MAP=y
CONFIG_ARCH_SUPPORTS_DEBUG_PAGEALLOC=y
CONFIG_ARCH_SUPPORTS_MSI=y
CONFIG_ARCH_SUPPORTS_OPTIMIZED_INLINING=y
CONFIG_ARCH_SUSPEND_POSSIBLE=y
CONFIG_ARCH_WANT_FRAME_POINTERS=y
CONFIG_ARCH_WANT_OPTIONAL_GPIOLIB=y
CONFIG_CLOCKSOURCE_WATCHDOG=y
CONFIG_DEFAULT_SECURITY_APPARMOR=n
CONFIG_DEFAULT_SECURITY_DAC=n
CONFIG_DEFAULT_SECURITY_SELINUX=y
CONFIG_DEFAULT_SECURITY_SMACK=n
CONFIG_DEFAULT_SECURITY_TOMOYO=n
CONFIG_DYNAMIC_FTRACE=y
CONFIG_FUTEX=y
CONFIG_GENERIC_CALIBRATE_DELAY=y
CONFIG_GENERIC_CLOCKEVENTS=y
CONFIG_GENERIC_CMOS_UPDATE=y
CONFIG_GENERIC_FIND_FIRST_BIT=y
CONFIG_GENERIC_FIND_LAST_BIT=y
CONFIG_GENERIC_FIND_NEXT_BIT=y
CONFIG_GENERIC_HWEIGHT=y
CONFIG_GENERIC_IOMAP=y
CONFIG_GENERIC_IRQ_PROBE=y
CONFIG_GENERIC_ISA_DMA=y
CONFIG_GENERIC_PENDING_IRQ=y
CONFIG_HAS_IOMEM=y
CONFIG_HAVE_AOUT=y
CONFIG_HAVE_ARCH_JUMP_LABEL=y
CONFIG_HAVE_ARCH_KGDB=y
CONFIG_HAVE_ARCH_KMEMCHECK=y
CONFIG_HAVE_ARCH_TRACEHOOK=y
CONFIG_HAVE_C_RECORDMCOUNT=y
CONFIG_HAVE_DMA_API_DEBUG=y
CONFIG_HAVE_DMA_ATTRS=y
CONFIG_HAVE_DYNAMIC_FTRACE=y
CONFIG_HAVE_EFFICIENT_UNALIGNED_ACCESS=y
CONFIG_HAVE_FTRACE_MCOUNT_RECORD=y
CONFIG_HAVE_FTRACE_NMI_ENTER=y
CONFIG_HAVE_FUNCTION_GRAPH_FP_TEST=y
CONFIG_HAVE_FUNCTION_GRAPH_TRACER=y
CONFIG_HAVE_FUNCTION_TRACER=y
CONFIG_HAVE_FUNCTION_TRACE_MCOUNT_TEST=y
CONFIG_HAVE_GENERIC_DMA_COHERENT=y
CONFIG_HAVE_GENERIC_HARDIRQS=y
CONFIG_HAVE_HW_BREAKPOINT=y
CONFIG_HAVE_IDE=y
CONFIG_HAVE_IOREMAP_PROT=y
CONFIG_HAVE_IRQ_WORK=y
CONFIG_HAVE_KERNEL_BZIP2=y
CONFIG_HAVE_KERNEL_GZIP=y
CONFIG_HAVE_KERNEL_LZMA=y
CONFIG_HAVE_KERNEL_LZO=y
CONFIG_HAVE_KPROBES=y
CONFIG_HAVE_KRETPROBES=y
CONFIG_HAVE_KVM=y
CONFIG_HAVE_LATENCYTOP_SUPPORT=y
CONFIG_HAVE_MEMBLOCK=y
CONFIG_HAVE_MIXED_BREAKPOINTS_REGS=y
CONFIG_HAVE_MMIOTRACE_SUPPORT=y
CONFIG_HAVE_OPROFILE=y
CONFIG_HAVE_OPTPROBES=y
CONFIG_HAVE_PERF_EVENTS=y
CONFIG_HAVE_PERF_EVENTS_NMI=y
CONFIG_HAVE_REGS_AND_STACK_ACCESS_API=y
CONFIG_HAVE_SETUP_PER_CPU_AREA=y
CONFIG_HAVE_SPARSE_IRQ=y
CONFIG_HAVE_SYSCALL_TRACEPOINTS=y
CONFIG_HAVE_TEXT_POKE_SMP=y
CONFIG_HAVE_UNSTABLE_SCHED_CLOCK=y
CONFIG_HAVE_USER_RETURN_NOTIFIER=y
CONFIG_HZ_100=y
CONFIG_HZ_1000=n
CONFIG_HZ_250=n
CONFIG_HZ_300=n
CONFIG_I2C=y
CONFIG_I2C_MODULE=n
CONFIG_INPUT=y
CONFIG_INPUT_MODULE=n
CONFIG_IO_DELAY_0X80=y
CONFIG_IO_DELAY_0XED=n
CONFIG_IO_DELAY_NONE=n
CONFIG_IO_DELAY_UDELAY=n
CONFIG_ISA_DMA_API=y
CONFIG_LOCKDEP_SUPPORT=y
CONFIG_MMU=y
CONFIG_MODULES=y
CONFIG_NEED_PER_CPU_EMBED_FIRST_CHUNK=y
CONFIG_NEED_PER_CPU_PAGE_FIRST_CHUNK=y
CONFIG_NEED_SG_DMA_LENGTH=y
CONFIG_NO_BOOTMEM=y
CONFIG_PCI=y
CONFIG_PERF_EVENTS=y
CONFIG_PREEMPT=n
CONFIG_PREEMPT_NONE=y
CONFIG_PREEMPT_VOLUNTARY=n
CONFIG_RT_MUTEXES=y
CONFIG_SLAB=y
CONFIG_SLOB=n
CONFIG_SLUB=n
CONFIG_SMP=y
CONFIG_SND=y
CONFIG_SND_AC97_CODEC=y
CONFIG_SND_AC97_CODEC_MODULE=n
CONFIG_SND_CA0106=y
CONFIG_SND_CA0106_MODULE=n
CONFIG_SND_HDA_INTEL=y
CONFIG_SND_HDA_INTEL_MODULE=n
CONFIG_SND_ICE1724=y
CONFIG_SND_ICE1724_MODULE=n
CONFIG_SND_MODULE=n
CONFIG_SND_PCI=y
CONFIG_SND_POWERMAC=n
CONFIG_SND_POWERMAC_MODULE=n
CONFIG_SND_PPC=n
CONFIG_SND_VMASTER=y
CONFIG_SOUND=y
CONFIG_SOUND_MODULE=n
CONFIG_STACKTRACE_SUPPORT=y
CONFIG_TINY_PREEMPT_RCU=n
CONFIG_TINY_RCU=n
CONFIG_TRACE_IRQFLAGS_SUPPORT=y
CONFIG_TREE_PREEMPT_RCU=n
CONFIG_TREE_RCU=y
CONFIG_USER_STACKTRACE_SUPPORT=y
CONFIG_X86=y
CONFIG_X86_32=y
CONFIG_X86_32_NON_STANDARD=y
CONFIG_X86_64=n
CONFIG_X86_CPU=y
CONFIG_X86_EXTENDED_PLATFORM=y
CONFIG_X86_IO_APIC=y
CONFIG_X86_LOCAL_APIC=y
CONFIG_X86_UP_APIC=n
CONFIG_ZONE_DMA=y
# CONFIG_M68K=n
# CONFIG_NO_IOMEM=n
# CONFIG_PPC=n
# CONFIG_PPC_PMAC=n
# CONFIG_S390=n
 * check-output-end
 */

==> undertaker_1.6.orig.tar.xz: undertaker-1.6/undertaker/validation/checkexpr_complex.c <==
/*
 * check-name: find interesting items for symbol
 * check-command: undertaker -j checkexpr -m ../kconfig-dumps/models/x86.model CONFIG_SND_HDA_INTEL
 * check-output-start
CONFIG_64BIT=n
CONFIG_ALPHA=n
CONFIG_ANON_INODES=y
CONFIG_ARCH_HAS_CACHE_LINE_SIZE=y
CONFIG_ARCH_HAS_CPU_IDLE_WAIT=y
CONFIG_ARCH_HAS_CPU_RELAX=y
CONFIG_ARCH_HAS_DEFAULT_IDLE=y
CONFIG_ARCH_HAVE_NMI_SAFE_CMPXCHG=y
CONFIG_ARCH_HIBERNATION_POSSIBLE=y
CONFIG_ARCH_POPULATES_NODE_MAP=y
CONFIG_ARCH_SUPPORTS_DEBUG_PAGEALLOC=y
CONFIG_ARCH_SUPPORTS_MSI=y
CONFIG_ARCH_SUPPORTS_OPTIMIZED_INLINING=y
CONFIG_ARCH_SUSPEND_POSSIBLE=y
CONFIG_ARCH_WANT_FRAME_POINTERS=y
CONFIG_ARCH_WANT_OPTIONAL_GPIOLIB=y
CONFIG_ARM=n
CONFIG_AVR32=n
CONFIG_BLACKFIN=n
CONFIG_CLKEVT_I8253=y
CONFIG_CLKSRC_I8253=y
CONFIG_CLOCKSOURCE_WATCHDOG=y
CONFIG_CMPXCHG_DOUBLE=y
CONFIG_CRIS=n
CONFIG_DEFAULT_SECURITY_APPARMOR=y
CONFIG_DEFAULT_SECURITY_DAC=n
CONFIG_DEFAULT_SECURITY_SELINUX=n
CONFIG_DEFAULT_SECURITY_SMACK=n
CONFIG_DEFAULT_SECURITY_TOMOYO=n
CONFIG_DYNAMIC_FTRACE=y
CONFIG_FRV=n
CONFIG_FUTEX=y
CONFIG_GENERIC_CALIBRATE_DELAY=y
CONFIG_GENERIC_CLOCKEVENTS=y
CONFIG_GENERIC_CLOCKEVENTS_MIN_ADJUST=y
CONFIG_GENERIC_CMOS_UPDATE=y
CONFIG_GENERIC_CPU=y
CONFIG_GENERIC_FIND_FIRST_BIT=y
CONFIG_GENERIC_HWEIGHT=y
CONFIG_GENERIC_IOMAP=y
CONFIG_GENERIC_IRQ_PROBE=y
CONFIG_GENERIC_IRQ_SHOW=y
CONFIG_GENERIC_PENDING_IRQ=y
CONFIG_H8300=n
CONFIG_HAS_IOMEM=y
CONFIG_HAVE_AOUT=y
CONFIG_HAVE_ARCH_JUMP_LABEL=y
CONFIG_HAVE_ARCH_KGDB=y
CONFIG_HAVE_ARCH_KMEMCHECK=y
CONFIG_HAVE_ARCH_TRACEHOOK=y
CONFIG_HAVE_BPF_JIT=y
CONFIG_HAVE_C_RECORDMCOUNT=y
CONFIG_HAVE_DMA_API_DEBUG=y
CONFIG_HAVE_DMA_ATTRS=y
CONFIG_HAVE_DYNAMIC_FTRACE=y
CONFIG_HAVE_EFFICIENT_UNALIGNED_ACCESS=y
CONFIG_HAVE_FTRACE_MCOUNT_RECORD=y
CONFIG_HAVE_FTRACE_NMI_ENTER=y
CONFIG_HAVE_FUNCTION_GRAPH_FP_TEST=y
CONFIG_HAVE_FUNCTION_GRAPH_TRACER=y
CONFIG_HAVE_FUNCTION_TRACER=y
CONFIG_HAVE_FUNCTION_TRACE_MCOUNT_TEST=y
CONFIG_HAVE_GENERIC_DMA_COHERENT=y
CONFIG_HAVE_GENERIC_HARDIRQS=y
CONFIG_HAVE_HW_BREAKPOINT=y
CONFIG_HAVE_IDE=y
CONFIG_HAVE_IOREMAP_PROT=y
CONFIG_HAVE_IRQ_WORK=y
CONFIG_HAVE_KERNEL_BZIP2=y
CONFIG_HAVE_KERNEL_GZIP=y
CONFIG_HAVE_KERNEL_LZMA=y
CONFIG_HAVE_KERNEL_LZO=y
CONFIG_HAVE_KERNEL_XZ=y
CONFIG_HAVE_KPROBES=y
CONFIG_HAVE_KRETPROBES=y
CONFIG_HAVE_KVM=y
CONFIG_HAVE_LATENCYTOP_SUPPORT=y
CONFIG_HAVE_MEMBLOCK=y
CONFIG_HAVE_MIXED_BREAKPOINTS_REGS=y
CONFIG_HAVE_MMIOTRACE_SUPPORT=y
CONFIG_HAVE_OPROFILE=y
CONFIG_HAVE_OPTPROBES=y
CONFIG_HAVE_PCSPKR_PLATFORM=y
CONFIG_HAVE_PERF_EVENTS=y
CONFIG_HAVE_PERF_EVENTS_NMI=y
CONFIG_HAVE_REGS_AND_STACK_ACCESS_API=y
CONFIG_HAVE_SETUP_PER_CPU_AREA=y
CONFIG_HAVE_SPARSE_IRQ=y
CONFIG_HAVE_SYSCALL_TRACEPOINTS=y
CONFIG_HAVE_TEXT_POKE_SMP=y
CONFIG_HAVE_UNSTABLE_SCHED_CLOCK=y
CONFIG_HAVE_USER_RETURN_NOTIFIER=y
CONFIG_HEXAGON=n
CONFIG_HZ_100=n
CONFIG_HZ_1000=y
CONFIG_HZ_250=n
CONFIG_HZ_300=n
CONFIG_I2C=y
CONFIG_I2C_MODULE=n
CONFIG_IA64=n
CONFIG_INPUT=y
CONFIG_INPUT_MODULE=n
CONFIG_IO_DELAY_0X80=y
CONFIG_IO_DELAY_0XED=n
CONFIG_IO_DELAY_NONE=n
CONFIG_IO_DELAY_UDELAY=n
CONFIG_IRQ_FORCED_THREADING=y
CONFIG_LOCKDEP_SUPPORT=y
CONFIG_M32R=n
CONFIG_M386=n
CONFIG_M486=n
CONFIG_M586=n
CONFIG_M586MMX=n
CONFIG_M586TSC=n
CONFIG_M686=n
CONFIG_MATOM=n
CONFIG_MCORE2=n
CONFIG_MCRUSOE=n
CONFIG_MCYRIXIII=n
CONFIG_MEFFICEON=n
CONFIG_MELAN=n
CONFIG_MGEODEGX1=n
CONFIG_MGEODE_LX=n
CONFIG_MICROBLAZE=n
CONFIG_MIPS=n
CONFIG_MK6=n
CONFIG_MK7=n
CONFIG_MK8=n
CONFIG_MMU=y
CONFIG_MN10300=n
CONFIG_MODULES=y
CONFIG_MPENTIUM4=n
CONFIG_MPENTIUMII=n
CONFIG_MPENTIUMIII=n
CONFIG_MPENTIUMM=n
CONFIG_MPSC=n
CONFIG_MVIAC3_2=n
CONFIG_MVIAC7=n
CONFIG_MWINCHIP3D=n
CONFIG_MWINCHIPC6=n
CONFIG_NEED_PER_CPU_EMBED_FIRST_CHUNK=y
CONFIG_NEED_PER_CPU_PAGE_FIRST_CHUNK=y
CONFIG_NEED_SG_DMA_LENGTH=y
CONFIG_NET=y
CONFIG_NO_BOOTMEM=y
CONFIG_OPENRISC=n
CONFIG_PARISC=n
CONFIG_PCI=y
CONFIG_PERF_EVENTS=y
CONFIG_POWERPC=n
CONFIG_PREEMPT=y
CONFIG_PREEMPT_NONE=n
CONFIG_PREEMPT_VOLUNTARY=n
CONFIG_RT_MUTEXES=y
CONFIG_SCORE=n
CONFIG_SH=n
CONFIG_SLAB=y
CONFIG_SLOB=n
CONFIG_SLUB=n
CONFIG_SMP=y
CONFIG_SND=y
CONFIG_SND_AC97_CODEC=y
CONFIG_SND_AC97_CODEC_MODULE=n
CONFIG_SND_CA0106=y
CONFIG_SND_CA0106_MODULE=n
CONFIG_SND_HDA_INTEL=y
CONFIG_SND_HDA_INTEL_MODULE=n
CONFIG_SND_ICE1724=y
CONFIG_SND_ICE1724_MODULE=n
CONFIG_SND_MODULE=n
CONFIG_SND_PCI=y
CONFIG_SND_POWERMAC=n
CONFIG_SND_POWERMAC_MODULE=n
CONFIG_SND_PPC=n
CONFIG_SND_VMASTER=y
CONFIG_SOUND=y
CONFIG_SOUND_MODULE=n
CONFIG_SPARC=n
CONFIG_SPARSE_IRQ=y
CONFIG_STACKTRACE_SUPPORT=y
CONFIG_TILE=n
CONFIG_TINY_PREEMPT_RCU=y
CONFIG_TINY_RCU=n
CONFIG_TRACE_IRQFLAGS_SUPPORT=y
CONFIG_TREE_PREEMPT_RCU=n
CONFIG_TREE_RCU=n
CONFIG_UM=n
CONFIG_UNICORE32=n
CONFIG_USER_STACKTRACE_SUPPORT=y
CONFIG_USE_GENERIC_SMP_HELPERS=y
CONFIG_X86=y
CONFIG_X86_32=y
CONFIG_X86_32_NON_STANDARD=y
CONFIG_X86_64=n
CONFIG_X86_EXTENDED_PLATFORM=y
CONFIG_X86_IO_APIC=y
CONFIG_X86_LOCAL_APIC=y
CONFIG_X86_UP_APIC=n
CONFIG_X86_UP_IOAPIC=n
CONFIG_XTENSA=n
CONFIG_n=y
# CONFIG_M68K=n
# CONFIG_NO_IOMEM=n
# CONFIG_PPC=n
# CONFIG_PPC_PMAC=n
# CONFIG_S390=n
# CONFIG_UML=n
 * check-output-end
 */
